@@ -1,6 +1,7 @@
 """ SseqChart is the main class which holds the data structure representing the chart. """
 
 
+from spectralsequence_chart.signal_dict import SignalList
 import threading
 from typing import (
     Any, Dict, Iterable, List, 
@@ -40,7 +41,7 @@ class SseqChart:
 
         self._uuid = str(uuid4())
 
-        self._page_list =  [(2, INFINITY), (INFINITY, INFINITY)]
+        self._page_list =  SignalList([(2, INFINITY), (INFINITY, INFINITY)], callback=self._add_setting_message)
         self._initial_x_range = (0, 10)
         self._initial_y_range = (0, 10)
         self._x_range = (0, 10)
@@ -161,6 +162,7 @@ class SseqChart:
         assert type == SseqChart.__name__
         self._uuid = uuid
         self._page_list = page_list
+        page_list.set_callback(self._add_setting_message)
         self._initial_x_range = initial_x_range
         self._initial_y_range = initial_y_range
         self._x_range = x_range
@@ -212,11 +214,15 @@ class SseqChart:
         """ Add a differential.
 
             Args:
+
                 page (int): which page should the differential appear on.
+
                 source_arg (ChartClassArg): The source class, specified by either a `ChartClass` or a tuple with the bidegree and index of the class.
+
                 target_arg (ChartClassArg): The target class, specified by either a `ChartClass` or a tuple with the bidegree and index of the class.
+
                 auto (bool, optional): If 'True', automatically set max_page of source and target to 'page'. 
-                    If False, the edge will be added but no change will be made to the source or target classes. Defaults to 'True'.
+                If False, the edge will be added but no change will be made to the source or target classes. Defaults to 'True'.
             
             Returns: The added differential.
         """
@@ -296,7 +302,6 @@ class SseqChart:
             else:
                 idx = len(self.page_list)
             self.page_list.insert(idx, page_range)
-            self._add_setting_message()
     
 
     def _add_class_to_update(self, c : ChartClass):
@@ -632,6 +637,12 @@ class SseqChart:
         """
         return self._page_list
 
+    @page_list.setter
+    def page_list(self, v : List[Tuple[int, int]]):
+        self._page_list = SignalList(v, callback=self._add_setting_message)
+        self._add_setting_message()
+
+
     def register_class_style(self, class_style : ChartClassStyle):
         """ Register class style. This uses `class_style.group_name <ChartClassStyle.group_name>` as an index.
             Once registered, `class_style.group_name <ChartClassStyle.group_name>` may be used as a style in the arguments of 
